@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk2Gui_WLabel_SetIntProperty(GWEN_WIDGET *w,
                                   GWEN_DIALOG_PROPERTY prop,
-                                  int index,
+                                  GWEN_UNUSED int index,
                                   int value,
-                                  int doSignal) {
+                                  GWEN_UNUSED int doSignal)
+{
   GtkLabel *g;
 
   g=GTK_LABEL(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -52,14 +53,15 @@ int Gtk2Gui_WLabel_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WLabel_GetIntProperty(GWEN_WIDGET *w,
                                   GWEN_DIALOG_PROPERTY prop,
-                                  int index,
-                                  int defaultValue) {
+                                  GWEN_UNUSED int index,
+                                  int defaultValue)
+{
   GtkLabel *g;
 
   g=GTK_LABEL(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -87,9 +89,10 @@ int Gtk2Gui_WLabel_GetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WLabel_SetCharProperty(GWEN_WIDGET *w,
                                    GWEN_DIALOG_PROPERTY prop,
-                                   int index,
+                                   GWEN_UNUSED int index,
                                    const char *value,
-                                   int doSignal) {
+                                   GWEN_UNUSED int doSignal)
+{
   GtkLabel *g;
   GWEN_BUFFER *tbuf;
 
@@ -100,7 +103,7 @@ int Gtk2Gui_WLabel_SetCharProperty(GWEN_WIDGET *w,
   if (value && *value)
     Gtk2Gui_GetRawText(value, tbuf);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     gtk_label_set_text(g, GWEN_Buffer_GetStart(tbuf));
     GWEN_Buffer_free(tbuf);
@@ -119,16 +122,17 @@ int Gtk2Gui_WLabel_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WLabel_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WLabel_GetCharProperty(GWEN_WIDGET *w,
+                                           GWEN_DIALOG_PROPERTY prop,
+                                           GWEN_UNUSED int index,
+                                           const char *defaultValue)
+{
   GtkLabel *g;
 
   g=GTK_LABEL(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     return gtk_label_get_label(g);
   default:
@@ -143,14 +147,15 @@ const char* Gtk2Gui_WLabel_GetCharProperty(GWEN_WIDGET *w,
 
 
 
-int Gtk2Gui_WLabel_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WLabel_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
+  /*uint32_t flags;*/
   GWEN_WIDGET *wParent;
   GWEN_BUFFER *tbuf;
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   wParent=GWEN_Widget_Tree_GetParent(w);
   s=GWEN_Widget_GetText(w, 0);
 
@@ -160,8 +165,8 @@ int Gtk2Gui_WLabel_Setup(GWEN_WIDGET *w) {
 
   g=gtk_label_new(GWEN_Buffer_GetStart(tbuf));
   GWEN_Buffer_free(tbuf);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WLabel_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WLabel_GetIntProperty);
