@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk2Gui_WTextEdit_SetIntProperty(GWEN_WIDGET *w,
                                      GWEN_DIALOG_PROPERTY prop,
-                                     int index,
+                                     GWEN_UNUSED int index,
                                      int value,
-                                     int doSignal) {
+                                     GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -52,14 +53,15 @@ int Gtk2Gui_WTextEdit_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WTextEdit_GetIntProperty(GWEN_WIDGET *w,
                                      GWEN_DIALOG_PROPERTY prop,
-                                     int index,
-                                     int defaultValue) {
+                                     GWEN_UNUSED int index,
+                                     int defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -87,15 +89,16 @@ int Gtk2Gui_WTextEdit_GetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WTextEdit_SetCharProperty(GWEN_WIDGET *w,
                                       GWEN_DIALOG_PROPERTY prop,
-                                      int index,
+                                      GWEN_UNUSED int index,
                                       const char *value,
-                                      int doSignal) {
+                                      GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value: {
     GtkTextBuffer *tb;
     GtkTextIter endIter;
@@ -124,16 +127,17 @@ int Gtk2Gui_WTextEdit_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WTextEdit_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WTextEdit_GetCharProperty(GWEN_WIDGET *w,
+                                              GWEN_DIALOG_PROPERTY prop,
+                                              GWEN_UNUSED int index,
+                                              const char *defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value: {
     GtkTextBuffer *tb;
     GtkTextIter startIter;
@@ -167,7 +171,8 @@ const char* Gtk2Gui_WTextEdit_GetCharProperty(GWEN_WIDGET *w,
 
 
 
-static void Gtk2Gui_WTextEdit_Changed_handler(GtkTextBuffer *buffer, gpointer data) {
+static void Gtk2Gui_WTextEdit_Changed_handler(GWEN_UNUSED GtkTextBuffer *buffer, gpointer data)
+{
   GWEN_WIDGET *w;
   int rv;
 
@@ -184,14 +189,15 @@ static void Gtk2Gui_WTextEdit_Changed_handler(GtkTextBuffer *buffer, gpointer da
 
 
 
-int Gtk2Gui_WTextEdit_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WTextEdit_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
+  /*uint32_t flags;*/
   GWEN_WIDGET *wParent;
-  gulong changed_handler_id;
+  /*gulong changed_handler_id;*/
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   wParent=GWEN_Widget_Tree_GetParent(w);
   s=GWEN_Widget_GetText(w, 0);
 
@@ -200,18 +206,18 @@ int Gtk2Gui_WTextEdit_Setup(GWEN_WIDGET *w) {
   if (s && *s)
     gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(g)), s, -1);
 
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WTextEdit_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WTextEdit_GetIntProperty);
   GWEN_Widget_SetSetCharPropertyFn(w, Gtk2Gui_WTextEdit_SetCharProperty);
   GWEN_Widget_SetGetCharPropertyFn(w, Gtk2Gui_WTextEdit_GetCharProperty);
 
-  changed_handler_id=g_signal_connect(gtk_text_view_get_buffer(GTK_TEXT_VIEW(g)),
-                                      "changed",
-                                      G_CALLBACK (Gtk2Gui_WTextEdit_Changed_handler),
-                                      w);
+  /*changed_handler_id=*/g_signal_connect(gtk_text_view_get_buffer(GTK_TEXT_VIEW(g)),
+                                          "changed",
+                                          G_CALLBACK(Gtk2Gui_WTextEdit_Changed_handler),
+                                          w);
 
   if (wParent)
     GWEN_Widget_AddChildGuiWidget(wParent, w);
