@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk3Gui_WRadioButton_SetIntProperty(GWEN_WIDGET *w,
                                         GWEN_DIALOG_PROPERTY prop,
-                                        int index,
+                                        GWEN_UNUSED int index,
                                         int value,
-                                        int doSignal) {
+                                        GWEN_UNUSED int doSignal)
+{
   GtkButton *g;
 
   g=GTK_BUTTON(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -56,14 +57,15 @@ int Gtk3Gui_WRadioButton_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk3Gui_WRadioButton_GetIntProperty(GWEN_WIDGET *w,
                                         GWEN_DIALOG_PROPERTY prop,
-                                        int index,
-                                        int defaultValue) {
+                                        GWEN_UNUSED int index,
+                                        int defaultValue)
+{
   GtkButton *g;
 
   g=GTK_BUTTON(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -92,16 +94,17 @@ int Gtk3Gui_WRadioButton_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk3Gui_WRadioButton_SetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *value,
-    int doSignal) {
+                                         GWEN_DIALOG_PROPERTY prop,
+                                         GWEN_UNUSED int index,
+                                         const char *value,
+                                         GWEN_UNUSED int doSignal)
+{
   GtkButton *g;
 
   g=GTK_BUTTON(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     gtk_button_set_label(g, value);
     return 0;
@@ -118,16 +121,17 @@ int Gtk3Gui_WRadioButton_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk3Gui_WRadioButton_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk3Gui_WRadioButton_GetCharProperty(GWEN_WIDGET *w,
+                                                 GWEN_DIALOG_PROPERTY prop,
+                                                 GWEN_UNUSED int index,
+                                                 const char *defaultValue)
+{
   GtkButton *g;
 
   g=GTK_BUTTON(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     return gtk_button_get_label(g);
   default:
@@ -142,7 +146,8 @@ const char* Gtk3Gui_WRadioButton_GetCharProperty(GWEN_WIDGET *w,
 
 
 
-static void Gtk3Gui_WRadioButton_Toggled_handler(GtkButton *button, gpointer data) {
+static void Gtk3Gui_WRadioButton_Toggled_handler(GWEN_UNUSED GtkButton *button, gpointer data)
+{
   GWEN_WIDGET *w;
   int rv;
 
@@ -159,16 +164,15 @@ static void Gtk3Gui_WRadioButton_Toggled_handler(GtkButton *button, gpointer dat
 
 
 
-int Gtk3Gui_WRadioButton_Setup(GWEN_WIDGET *w) {
+int Gtk3Gui_WRadioButton_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
   GWEN_WIDGET *wParent;
   GWEN_WIDGET *wT;
-  gulong toggled_handler_id;
+  /*gulong toggled_handler_id;*/
   int groupId;
 
-  flags=GWEN_Widget_GetFlags(w);
   wParent=GWEN_Widget_Tree_GetParent(w);
   groupId=GWEN_Widget_GetGroupId(w);
 
@@ -182,11 +186,11 @@ int Gtk3Gui_WRadioButton_Setup(GWEN_WIDGET *w) {
 
   /* get root widget */
   wT=wParent;
-  while(GWEN_Widget_Tree_GetParent(wT))
+  while (GWEN_Widget_Tree_GetParent(wT))
     wT=GWEN_Widget_Tree_GetParent(wT);
 
   /* get first radio button of the same group */
-  while(wT) {
+  while (wT) {
     if ((GWEN_Widget_GetType(wT)==GWEN_Widget_TypeRadioButton) &&
         GWEN_Widget_GetGroupId(wT)==groupId)
       break;
@@ -200,18 +204,18 @@ int Gtk3Gui_WRadioButton_Setup(GWEN_WIDGET *w) {
   }
 
   /* set pointers */
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk3Gui_WRadioButton_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk3Gui_WRadioButton_GetIntProperty);
   GWEN_Widget_SetSetCharPropertyFn(w, Gtk3Gui_WRadioButton_SetCharProperty);
   GWEN_Widget_SetGetCharPropertyFn(w, Gtk3Gui_WRadioButton_GetCharProperty);
 
-  toggled_handler_id=g_signal_connect(g,
-                                      "toggled",
-                                      G_CALLBACK (Gtk3Gui_WRadioButton_Toggled_handler),
-                                      w);
+  g_signal_connect(g,
+                   "toggled",
+                   G_CALLBACK(Gtk3Gui_WRadioButton_Toggled_handler),
+                   w);
 
   if (wParent)
     GWEN_Widget_AddChildGuiWidget(wParent, w);
