@@ -78,9 +78,9 @@ public:
 
 
   int setCharProperty(GWEN_DIALOG_PROPERTY prop,
-		      int index,
-		      const char *value,
-		      int doSignal) {
+                      int index,
+                      const char *value,
+                      int doSignal) {
     QWidget *qw;
 
     qw=(QWidget*) GWEN_Widget_GetImplData(_widget, QT4_DIALOG_WIDGET_REAL);
@@ -88,23 +88,23 @@ public:
 
     switch(prop) {
     case GWEN_DialogProperty_Title:
-      qw->setWindowTitle(value);
+      qw->setWindowTitle(QString::fromUtf8(value));
       return 0;
     default:
       break;
     }
 
     DBG_WARN(GWEN_LOGDOMAIN,
-	     "Function is not appropriate for this type of widget (%s)",
-	     GWEN_Widget_Type_toString(GWEN_Widget_GetType(_widget)));
+             "Function is not appropriate for this type of widget (%s)",
+             GWEN_Widget_Type_toString(GWEN_Widget_GetType(_widget)));
     return GWEN_ERROR_INVALID;
   };
 
 
 
   const char *getCharProperty(GWEN_DIALOG_PROPERTY prop,
-			      int index,
-			      const char *defaultValue) {
+                              int index,
+                              const char *defaultValue) {
     QWidget *qw;
     QString str;
 
@@ -115,10 +115,10 @@ public:
     case GWEN_DialogProperty_Title:
       str=qw->windowTitle();
       if (str.isEmpty())
-	return defaultValue;
+        return defaultValue;
       else {
-	GWEN_Widget_SetText(_widget, QT4_DIALOG_STRING_TITLE, str.toUtf8());
-	return GWEN_Widget_GetText(_widget, QT4_DIALOG_STRING_TITLE);
+        GWEN_Widget_SetText(_widget, QT4_DIALOG_STRING_TITLE, str.toUtf8());
+        return GWEN_Widget_GetText(_widget, QT4_DIALOG_STRING_TITLE);
       }
       break;
 
@@ -127,8 +127,8 @@ public:
     }
 
     DBG_WARN(GWEN_LOGDOMAIN,
-	     "Function is not appropriate for this type of widget (%s)",
-	     GWEN_Widget_Type_toString(GWEN_Widget_GetType(_widget)));
+             "Function is not appropriate for this type of widget (%s)",
+             GWEN_Widget_Type_toString(GWEN_Widget_GetType(_widget)));
     return defaultValue;
   };
 
