@@ -118,7 +118,7 @@ void GWEN_RefPtr_DelFlags(GWEN_REFPTR *rp, uint32_t fl);
  */
 /*@{*/
 GWENHYWFAR_API
-GWEN_REFPTR_INFO *GWEN_RefPtrInfo_new();
+GWEN_REFPTR_INFO *GWEN_RefPtrInfo_new(void);
 GWENHYWFAR_API
 void GWEN_RefPtrInfo_free(GWEN_REFPTR_INFO *rpi);
 GWENHYWFAR_API
@@ -149,7 +149,7 @@ void GWEN_RefPtrInfo_DelFlags(GWEN_REFPTR_INFO *rpi, uint32_t fl);
  */
 /*@{*/
 typedef void (*GWEN_REFPTR_INFO_FREE_FN)(void *dp);
-typedef void* (*GWEN_REFPTR_INFO_DUP_FN)(void *dp);
+typedef void *(*GWEN_REFPTR_INFO_DUP_FN)(void *dp);
 /*@}*/
 
 
