@@ -26,7 +26,11 @@
 /* This file is included by "simpleptrlist.c" */
 
 
-#if GWENHYWFAR_ENABLE_TESTCODE
+#include <gwenhywfar/testframework.h>
+#include "simpleptrlist-t.h"
+
+
+#ifdef GWENHYWFAR_ENABLE_TESTCODE
 
 
 #include <gwenhywfar/mdigest.h>
@@ -34,6 +38,7 @@
 
 
 
+
 /* ------------------------------------------------------------------------------------------------
  * type definitions
  * ------------------------------------------------------------------------------------------------
