@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
     begin       : Wed Mar 16 2005
-    copyright   : (C) 2005 by Martin Preuss
+    copyright   : (C) 2005-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -15,6 +12,9 @@
 #endif
 
 
+#define DISABLE_DEBUGLOG
+
+
 #include "cryptalgo_p.h"
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/debug.h>
@@ -25,7 +25,8 @@ GWEN_LIST2_FUNCTIONS(GWEN_CRYPT_CRYPTALGO, GWEN_Crypt_CryptAlgo)
 
 
 
-GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgoId_fromString(const char *s) {
+GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgoId_fromString(const char *s)
+{
   assert(s);
   if (strcasecmp(s, "none")==0)
     return GWEN_Crypt_CryptAlgoId_None;
@@ -35,10 +36,13 @@ GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgoId_fromString(const char *s) {
     return GWEN_Crypt_CryptAlgoId_Dsa;
   else if (strcasecmp(s, "des")==0)
     return GWEN_Crypt_CryptAlgoId_Des;
-  else if (strcasecmp(s, "des_3k")==0)
+  else if (strcasecmp(s, "des_3k")==0 ||
+           strcasecmp(s, "des3k")==0)
     return GWEN_Crypt_CryptAlgoId_Des3K;
   else if (strcasecmp(s, "blowfish")==0)
     return GWEN_Crypt_CryptAlgoId_BlowFish;
+  else if (strcasecmp(s, "aes128")==0)
+    return GWEN_Crypt_CryptAlgoId_Aes128;
   else if (strcasecmp(s, "any")==0)
     return GWEN_Crypt_CryptAlgoId_Any;
   return GWEN_Crypt_CryptAlgoId_Unknown;
@@ -46,8 +50,9 @@ GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgoId_fromString(const char *s) {
 
 
 
-const char *GWEN_Crypt_CryptAlgoId_toString(GWEN_CRYPT_CRYPTALGOID a) {
-  switch(a) {
+const char *GWEN_Crypt_CryptAlgoId_toString(GWEN_CRYPT_CRYPTALGOID a)
+{
+  switch (a) {
   case GWEN_Crypt_CryptAlgoId_None:
     return "none";
   case GWEN_Crypt_CryptAlgoId_Rsa:
@@ -60,6 +65,8 @@ const char *GWEN_Crypt_CryptAlgoId_toString(GWEN_CRYPT_CRYPTALGOID a) {
     return "des_3k";
   case GWEN_Crypt_CryptAlgoId_BlowFish:
     return "blowfish";
+  case GWEN_Crypt_CryptAlgoId_Aes128:
+    return "aes128";
   case GWEN_Crypt_CryptAlgoId_Any:
     return "any";
   default:
@@ -69,7 +76,8 @@ const char *GWEN_Crypt_CryptAlgoId_toString(GWEN_CRYPT_CRYPTALGOID a) {
 
 
 
-GWEN_CRYPT_CRYPTMODE GWEN_Crypt_CryptMode_fromString(const char *s) {
+GWEN_CRYPT_CRYPTMODE GWEN_Crypt_CryptMode_fromString(const char *s)
+{
   assert(s);
   if (strcasecmp(s, "none")==0)
     return GWEN_Crypt_CryptMode_None;
@@ -84,8 +92,9 @@ GWEN_CRYPT_CRYPTMODE GWEN_Crypt_CryptMode_fromString(const char *s) {
 
 
 
-const char *GWEN_Crypt_CryptMode_toString(GWEN_CRYPT_CRYPTMODE m) {
-  switch(m) {
+const char *GWEN_Crypt_CryptMode_toString(GWEN_CRYPT_CRYPTMODE m)
+{
+  switch (m) {
   case GWEN_Crypt_CryptMode_None:
     return "none";
   case GWEN_Crypt_CryptMode_Ecb:
@@ -102,7 +111,8 @@ const char *GWEN_Crypt_CryptMode_toString(GWEN_CRYPT_CRYPTMODE m) {
 
 
 GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_new(GWEN_CRYPT_CRYPTALGOID id,
-					       GWEN_CRYPT_CRYPTMODE m) {
+                                               GWEN_CRYPT_CRYPTMODE m)
+{
   GWEN_CRYPT_CRYPTALGO *a;
 
   GWEN_NEW_OBJECT(GWEN_CRYPT_CRYPTALGO, a);
@@ -116,7 +126,8 @@ GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_new(GWEN_CRYPT_CRYPTALGOID id,
 
 
 
-void GWEN_Crypt_CryptAlgo_Attach(GWEN_CRYPT_CRYPTALGO *a) {
+void GWEN_Crypt_CryptAlgo_Attach(GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
   a->refCount++;
@@ -124,7 +135,8 @@ void GWEN_Crypt_CryptAlgo_Attach(GWEN_CRYPT_CRYPTALGO *a) {
 
 
 
-GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_fromDb(GWEN_DB_NODE *db) {
+GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_fromDb(GWEN_DB_NODE *db)
+{
   const char *s;
 
   assert(db);
@@ -169,25 +181,26 @@ GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_fromDb(GWEN_DB_NODE *db) {
 
 
 
-int GWEN_Crypt_CryptAlgo_toDb(const GWEN_CRYPT_CRYPTALGO *a, GWEN_DB_NODE *db) {
+int GWEN_Crypt_CryptAlgo_toDb(const GWEN_CRYPT_CRYPTALGO *a, GWEN_DB_NODE *db)
+{
   assert(a);
   assert(a->refCount);
 
   GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		       "id",
-		       GWEN_Crypt_CryptAlgoId_toString(a->id));
+                       "id",
+                       GWEN_Crypt_CryptAlgoId_toString(a->id));
   GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		       "mode",
-		       GWEN_Crypt_CryptMode_toString(a->id));
+                       "mode",
+                       GWEN_Crypt_CryptMode_toString(a->mode));
   if (a->pInitVector && a->lInitVector)
     GWEN_DB_SetBinValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-			"initVector",
-			a->pInitVector, a->lInitVector);
+                        "initVector",
+                        a->pInitVector, a->lInitVector);
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "chunkSize",
+                      "chunkSize",
                       a->chunkSize);
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "keySizeInBits",
+                      "keySizeInBits",
                       a->keySizeInBits);
 
   return 0;
@@ -195,13 +208,14 @@ int GWEN_Crypt_CryptAlgo_toDb(const GWEN_CRYPT_CRYPTALGO *a, GWEN_DB_NODE *db) {
 
 
 
-GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_dup(const GWEN_CRYPT_CRYPTALGO *na) {
+GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_dup(const GWEN_CRYPT_CRYPTALGO *na)
+{
   GWEN_CRYPT_CRYPTALGO *a;
 
   assert(na);
   a=GWEN_Crypt_CryptAlgo_new(na->id, na->mode);
   if (na->pInitVector && na->lInitVector) {
-    a->pInitVector=(uint8_t*) malloc(na->lInitVector);
+    a->pInitVector=(uint8_t *) malloc(na->lInitVector);
     if (a->pInitVector==NULL) {
       GWEN_Crypt_CryptAlgo_free(a);
       return NULL;
@@ -217,13 +231,14 @@ GWEN_CRYPT_CRYPTALGO *GWEN_Crypt_CryptAlgo_dup(const GWEN_CRYPT_CRYPTALGO *na) {
 
 
 
-void GWEN_Crypt_CryptAlgo_free(GWEN_CRYPT_CRYPTALGO *a) {
+void GWEN_Crypt_CryptAlgo_free(GWEN_CRYPT_CRYPTALGO *a)
+{
   if (a) {
     assert(a->refCount);
     if (a->refCount==1) {
       if (a->pInitVector) {
-	free(a->pInitVector);
-	a->pInitVector=NULL;
+        free(a->pInitVector);
+        a->pInitVector=NULL;
       }
       a->refCount--;
       GWEN_FREE_OBJECT(a);
@@ -236,7 +251,8 @@ void GWEN_Crypt_CryptAlgo_free(GWEN_CRYPT_CRYPTALGO *a) {
 
 
 
-GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgo_GetId(const GWEN_CRYPT_CRYPTALGO *a){
+GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgo_GetId(const GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
   return a->id;
@@ -244,7 +260,8 @@ GWEN_CRYPT_CRYPTALGOID GWEN_Crypt_CryptAlgo_GetId(const GWEN_CRYPT_CRYPTALGO *a)
 
 
 
-GWEN_CRYPT_CRYPTMODE GWEN_Crypt_CryptAlgo_GetMode(const GWEN_CRYPT_CRYPTALGO *a) {
+GWEN_CRYPT_CRYPTMODE GWEN_Crypt_CryptAlgo_GetMode(const GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
   return a->mode;
@@ -252,7 +269,8 @@ GWEN_CRYPT_CRYPTMODE GWEN_Crypt_CryptAlgo_GetMode(const GWEN_CRYPT_CRYPTALGO *a)
 
 
 
-uint8_t *GWEN_Crypt_CryptAlgo_GetInitVectorPtr(const GWEN_CRYPT_CRYPTALGO *a){
+uint8_t *GWEN_Crypt_CryptAlgo_GetInitVectorPtr(const GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
   return a->pInitVector;
@@ -260,7 +278,8 @@ uint8_t *GWEN_Crypt_CryptAlgo_GetInitVectorPtr(const GWEN_CRYPT_CRYPTALGO *a){
 
 
 
-uint32_t GWEN_Crypt_CryptAlgo_GetInitVectorLen(const GWEN_CRYPT_CRYPTALGO *a){
+uint32_t GWEN_Crypt_CryptAlgo_GetInitVectorLen(const GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
   return a->lInitVector;
@@ -269,15 +288,16 @@ uint32_t GWEN_Crypt_CryptAlgo_GetInitVectorLen(const GWEN_CRYPT_CRYPTALGO *a){
 
 
 int GWEN_Crypt_CryptAlgo_SetInitVector(GWEN_CRYPT_CRYPTALGO *a,
-				       const uint8_t *pv,
-				       uint32_t lv) {
+                                       const uint8_t *pv,
+                                       uint32_t lv)
+{
   uint8_t *nv=NULL;
 
   assert(a);
   assert(a->refCount);
 
   if (pv && lv) {
-    nv=(uint8_t*) malloc(lv);
+    nv=(uint8_t *) malloc(lv);
     if (nv==NULL)
       return GWEN_ERROR_MEMORY_FULL;
     memmove(nv, pv, lv);
@@ -294,7 +314,8 @@ int GWEN_Crypt_CryptAlgo_SetInitVector(GWEN_CRYPT_CRYPTALGO *a,
 
 
 
-int GWEN_Crypt_CryptAlgo_GetChunkSize(const GWEN_CRYPT_CRYPTALGO *a) {
+int GWEN_Crypt_CryptAlgo_GetChunkSize(const GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
 
@@ -303,7 +324,8 @@ int GWEN_Crypt_CryptAlgo_GetChunkSize(const GWEN_CRYPT_CRYPTALGO *a) {
 
 
 
-void GWEN_Crypt_CryptAlgo_SetChunkSize(GWEN_CRYPT_CRYPTALGO *a, int s) {
+void GWEN_Crypt_CryptAlgo_SetChunkSize(GWEN_CRYPT_CRYPTALGO *a, int s)
+{
   assert(a);
   assert(a->refCount);
 
@@ -312,7 +334,8 @@ void GWEN_Crypt_CryptAlgo_SetChunkSize(GWEN_CRYPT_CRYPTALGO *a, int s) {
 
 
 
-int GWEN_Crypt_CryptAlgo_GetKeySizeInBits(const GWEN_CRYPT_CRYPTALGO *a) {
+int GWEN_Crypt_CryptAlgo_GetKeySizeInBits(const GWEN_CRYPT_CRYPTALGO *a)
+{
   assert(a);
   assert(a->refCount);
 
@@ -321,7 +344,8 @@ int GWEN_Crypt_CryptAlgo_GetKeySizeInBits(const GWEN_CRYPT_CRYPTALGO *a) {
 
 
 
-void GWEN_Crypt_CryptAlgo_SetKeySizeInBits(GWEN_CRYPT_CRYPTALGO *a, int s) {
+void GWEN_Crypt_CryptAlgo_SetKeySizeInBits(GWEN_CRYPT_CRYPTALGO *a, int s)
+{
   assert(a);
   assert(a->refCount);
 
