@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Jan 05 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -30,6 +27,9 @@
 # include <config.h>
 #endif
 
+#define DISABLE_DEBUGLOG
+
+
 #include "padd_p.h"
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/debug.h>
@@ -41,19 +41,21 @@
 #include <stdlib.h>
 
 
-static uint8_t nullarray[]={0, 0, 0, 0, 0, 0, 0, 0};
+static uint8_t nullarray[]= {0, 0, 0, 0, 0, 0, 0, 0};
 
 
 /*
  * This code has been taken from OpenHBCI (rsakey.cpp, written by Fabian
  * Kaiser)
  */
-unsigned char GWEN_Padd_permutate(unsigned char input) {
+unsigned char GWEN_Padd_permutate(unsigned char input)
+{
   unsigned char leftNibble;
   unsigned char rightNibble;
-  static const unsigned char lookUp[2][16] =
-    {{0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15},
-    {14,3,5,8,9,4,2,15,0,13,11,6,7,10,12,1}};
+  static const unsigned char lookUp[2][16] = {
+    {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
+    {14, 3, 5, 8, 9, 4, 2, 15, 0, 13, 11, 6, 7, 10, 12, 1}
+  };
 
   rightNibble = input & 15;
   leftNibble = input & 240;
@@ -71,7 +73,8 @@ unsigned char GWEN_Padd_permutate(unsigned char input) {
  * The original code (in C++) has been written by Fabian Kaiser for OpenHBCI
  * (file rsakey.cpp). Translated to C by Martin Preuss
  */
-int GWEN_Padd_PaddWithISO9796(GWEN_BUFFER *src) {
+int GWEN_Padd_PaddWithISO9796(GWEN_BUFFER *src)
+{
   unsigned char *p;
   unsigned int l;
   unsigned int i;
@@ -79,17 +82,17 @@ int GWEN_Padd_PaddWithISO9796(GWEN_BUFFER *src) {
   unsigned char hash[20];
   unsigned char c;
 
-  p=(unsigned char*)GWEN_Buffer_GetStart(src);
+  p=(unsigned char *)GWEN_Buffer_GetStart(src);
   l=GWEN_Buffer_GetUsedBytes(src);
   memmove(hash, p, l);
 
   /* src+src+src */
-  if (GWEN_Buffer_AppendBytes(src, (const char*)hash, l)) {
+  if (GWEN_Buffer_AppendBytes(src, (const char *)hash, l)) {
     DBG_INFO(GWEN_LOGDOMAIN, "here");
     return -1;
   }
 
-  if (GWEN_Buffer_AppendBytes(src, (const char*)hash, l)) {
+  if (GWEN_Buffer_AppendBytes(src, (const char *)hash, l)) {
     DBG_INFO(GWEN_LOGDOMAIN, "here");
     return -1;
   }
@@ -103,7 +106,7 @@ int GWEN_Padd_PaddWithISO9796(GWEN_BUFFER *src) {
   memset(buffer, 0, sizeof(buffer));
 
   /* append redundancy */
-  p=(unsigned char*)GWEN_Buffer_GetStart(src);
+  p=(unsigned char *)GWEN_Buffer_GetStart(src);
   for (i=0; i<=47; i++) {
     int j1, j2, j3;
 
@@ -133,7 +136,7 @@ int GWEN_Padd_PaddWithISO9796(GWEN_BUFFER *src) {
   p[sizeof(buffer) - 40] = p[sizeof(buffer) - 40] ^ 1;
 
   GWEN_Buffer_Reset(src);
-  if (GWEN_Buffer_AppendBytes(src, (const char*)buffer, sizeof(buffer))) {
+  if (GWEN_Buffer_AppendBytes(src, (const char *)buffer, sizeof(buffer))) {
     DBG_INFO(GWEN_LOGDOMAIN, "here");
     return -1;
   }
@@ -142,7 +145,8 @@ int GWEN_Padd_PaddWithISO9796(GWEN_BUFFER *src) {
 }
 
 
-int GWEN_Padd_PaddWithIso9796_2(GWEN_BUFFER *buf, int dstSize){
+int GWEN_Padd_PaddWithIso9796_2(GWEN_BUFFER *buf, int dstSize)
+{
   unsigned int diff;
   char *p;
   int i;
@@ -162,8 +166,8 @@ int GWEN_Padd_PaddWithIso9796_2(GWEN_BUFFER *buf, int dstSize){
   diff=dstSize-GWEN_Buffer_GetUsedBytes(buf)-11+1;
   if (GWEN_Buffer_InsertRoom(buf, 1+diff+1+8)) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Could not insert room for %d bytes",
-	      1+diff+1+8);
+              "Could not insert room for %d bytes",
+              1+diff+1+8);
     return GWEN_ERROR_GENERIC;
   }
 
@@ -177,7 +181,7 @@ int GWEN_Padd_PaddWithIso9796_2(GWEN_BUFFER *buf, int dstSize){
   *(p++)=0x01;
 
   /* insert 8 random bytes */
-  GWEN_Crypt_Random(2, (uint8_t*)p, 8);
+  GWEN_Crypt_Random(2, (uint8_t *)p, 8);
   for (i=0; i<8; i++) {
     if (*p==0)
       /* TODO: Need to find a better but yet fast way */
@@ -189,7 +193,8 @@ int GWEN_Padd_PaddWithIso9796_2(GWEN_BUFFER *buf, int dstSize){
 }
 
 
-int GWEN_Padd_UnpaddWithIso9796_2(GWEN_BUFFER *buf){
+int GWEN_Padd_UnpaddWithIso9796_2(GWEN_BUFFER *buf)
+{
   uint32_t l;
   uint32_t realSize;
   const uint8_t *p;
@@ -200,14 +205,14 @@ int GWEN_Padd_UnpaddWithIso9796_2(GWEN_BUFFER *buf){
     return GWEN_ERROR_INVALID;
   }
 
-  p=(const uint8_t*)GWEN_Buffer_GetStart(buf);
+  p=(const uint8_t *)GWEN_Buffer_GetStart(buf);
   if (*p!=0x60) {
     DBG_ERROR(GWEN_LOGDOMAIN, "First byte is not a 0x60");
     return GWEN_ERROR_BAD_DATA;
   }
   p++;
   l=0;
-  while(*p==0x00) {
+  while (*p==0x00) {
     l++;
     p++;
   }
@@ -224,11 +229,12 @@ int GWEN_Padd_UnpaddWithIso9796_2(GWEN_BUFFER *buf){
 
 
 
-int GWEN_Padd_PaddWithAnsiX9_23(GWEN_BUFFER *src) {
+int GWEN_Padd_PaddWithAnsiX9_23ToMultipleOf(GWEN_BUFFER *src, int y)
+{
   unsigned char paddLength;
   unsigned int i;
 
-  paddLength=8-(GWEN_Buffer_GetUsedBytes(src) % 8);
+  paddLength=y-(GWEN_Buffer_GetUsedBytes(src) % y);
   for (i=0; i<paddLength; i++)
     GWEN_Buffer_AppendByte(src, paddLength);
   return 0;
@@ -236,13 +242,14 @@ int GWEN_Padd_PaddWithAnsiX9_23(GWEN_BUFFER *src) {
 
 
 
-int GWEN_Padd_UnpaddWithAnsiX9_23(GWEN_BUFFER *src) {
+int GWEN_Padd_UnpaddWithAnsiX9_23FromMultipleOf(GWEN_BUFFER *src, int y)
+{
   const char *p;
   unsigned int lastpos;
   unsigned char paddLength;
 
   lastpos=GWEN_Buffer_GetUsedBytes(src);
-  if (lastpos<8) {
+  if (lastpos<y) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Buffer too small");
     return -1;
   }
@@ -250,7 +257,7 @@ int GWEN_Padd_UnpaddWithAnsiX9_23(GWEN_BUFFER *src) {
 
   p=GWEN_Buffer_GetStart(src)+lastpos;
   paddLength=*p;
-  if (paddLength<1 || paddLength>8) {
+  if (paddLength<1 || paddLength>y) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Invalid padding (%d bytes ?)", paddLength);
     return -1;
   }
@@ -261,7 +268,22 @@ int GWEN_Padd_UnpaddWithAnsiX9_23(GWEN_BUFFER *src) {
 
 
 
-int GWEN_Padd_PaddWithPkcs1Bt1(GWEN_BUFFER *buf, int dstSize){
+int GWEN_Padd_PaddWithAnsiX9_23(GWEN_BUFFER *src)
+{
+  return GWEN_Padd_PaddWithAnsiX9_23ToMultipleOf(src, 8);
+}
+
+
+
+int GWEN_Padd_UnpaddWithAnsiX9_23(GWEN_BUFFER *src)
+{
+  return GWEN_Padd_UnpaddWithAnsiX9_23FromMultipleOf(src, 8);
+}
+
+
+
+int GWEN_Padd_PaddWithPkcs1Bt1(GWEN_BUFFER *buf, int dstSize)
+{
   unsigned int diff;
   char *p;
 
@@ -299,7 +321,8 @@ int GWEN_Padd_PaddWithPkcs1Bt1(GWEN_BUFFER *buf, int dstSize){
 
 
 
-int GWEN_Padd_PaddWithPkcs1Bt2(GWEN_BUFFER *buf, int dstSize){
+int GWEN_Padd_PaddWithPkcs1Bt2(GWEN_BUFFER *buf, int dstSize)
+{
   unsigned int diff;
   char *p;
   int i;
@@ -327,7 +350,7 @@ int GWEN_Padd_PaddWithPkcs1Bt2(GWEN_BUFFER *buf, int dstSize){
   p=GWEN_Buffer_GetStart(buf);
   *(p++)=0x00;
   *(p++)=0x02; /* block type 02 */
-  GWEN_Crypt_Random(2, (uint8_t*)p, diff-3);
+  GWEN_Crypt_Random(2, (uint8_t *)p, diff-3);
   for (i=0; i<diff-3; i++) {
     if (*p==0)
       /* TODO: Need to find a better but yet fast way */
@@ -341,7 +364,8 @@ int GWEN_Padd_PaddWithPkcs1Bt2(GWEN_BUFFER *buf, int dstSize){
 
 
 
-int GWEN_Padd__UnpaddWithPkcs1Bt1Or2(GWEN_BUFFER *buf) {
+int GWEN_Padd__UnpaddWithPkcs1Bt1Or2(GWEN_BUFFER *buf)
+{
   char *p;
   uint32_t len;
   uint32_t paddBytes;
@@ -351,7 +375,7 @@ int GWEN_Padd__UnpaddWithPkcs1Bt1Or2(GWEN_BUFFER *buf) {
   assert(len);
 
   p=GWEN_Buffer_GetStart(buf);
-  if  (*p==0) {
+  if (*p==0) {
     p++;
     len--;
   }
@@ -364,12 +388,14 @@ int GWEN_Padd__UnpaddWithPkcs1Bt1Or2(GWEN_BUFFER *buf) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Unsupported block type %02x", *p);
     return GWEN_ERROR_INVALID;
   }
-  p++; len--;
+  p++;
+  len--;
 
   /* skip padding bytes */
   paddBytes=0;
-  while(*p!=0x00 && len) {
-    p++; len--;
+  while (*p!=0x00 && len) {
+    p++;
+    len--;
     paddBytes++;
   }
 
@@ -377,7 +403,8 @@ int GWEN_Padd__UnpaddWithPkcs1Bt1Or2(GWEN_BUFFER *buf) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Bad padding");
     return GWEN_ERROR_INVALID;
   }
-  p++; len--;
+  p++;
+  len--;
 
   if (paddBytes<8) {
     /* at least 8 padding bytes are needed */
@@ -392,83 +419,87 @@ int GWEN_Padd__UnpaddWithPkcs1Bt1Or2(GWEN_BUFFER *buf) {
 
 
 
-int GWEN_Padd_UnpaddWithPkcs1Bt1(GWEN_BUFFER *src){
+int GWEN_Padd_UnpaddWithPkcs1Bt1(GWEN_BUFFER *src)
+{
   return GWEN_Padd__UnpaddWithPkcs1Bt1Or2(src);
 }
 
 
 
-int GWEN_Padd_UnpaddWithPkcs1Bt2(GWEN_BUFFER *src){
+int GWEN_Padd_UnpaddWithPkcs1Bt2(GWEN_BUFFER *src)
+{
   return GWEN_Padd__UnpaddWithPkcs1Bt1Or2(src);
 }
 
 
 
 int GWEN_Padd_MGF1(uint8_t *pDestBuffer,
-		   uint32_t lDestBuffer,
-		   const uint8_t *pSeed,
-		   uint32_t lSeed,
-		   GWEN_MDIGEST *md) {
-    uint32_t bytesLeft=lDestBuffer;
-    uint32_t i;
-    uint8_t counter[4];
-    uint8_t *p;
+                   uint32_t lDestBuffer,
+                   const uint8_t *pSeed,
+                   uint32_t lSeed,
+                   GWEN_MDIGEST *md)
+{
+  uint32_t bytesLeft=lDestBuffer;
+  uint32_t i;
+  uint8_t counter[4];
+  uint8_t *p;
 
-    p=pDestBuffer;
+  p=pDestBuffer;
 
-    for (i=0; bytesLeft>0; i++) {
-      int rv;
-      uint32_t l;
+  for (i=0; bytesLeft>0; i++) {
+    int rv;
+    uint32_t l;
 
-      counter[0]= (uint8_t)((i>>24) & 0xff);
-      counter[1]= (uint8_t)((i>>16) & 0xff);
-      counter[2]= (uint8_t)((i>>8) & 0xff);
-      counter[3]= (uint8_t)(i & 0xff);
+    counter[0]= (uint8_t)((i>>24) & 0xff);
+    counter[1]= (uint8_t)((i>>16) & 0xff);
+    counter[2]= (uint8_t)((i>>8) & 0xff);
+    counter[3]= (uint8_t)(i & 0xff);
 
-      rv=GWEN_MDigest_Begin(md);
-      if (rv<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	return rv;
-      }
-
-      rv=GWEN_MDigest_Update(md, pSeed, lSeed);
-      if (rv<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	return rv;
-      }
-
-      rv=GWEN_MDigest_Update(md, counter, 4);
-      if (rv<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	return rv;
-      }
-
-      rv=GWEN_MDigest_End(md);
-      if (rv<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	return rv;
-      }
-
-      l=GWEN_MDigest_GetDigestSize(md);
-      if (bytesLeft<l)
-	l=bytesLeft;
-      memmove(p, GWEN_MDigest_GetDigestPtr(md), l);
-      bytesLeft-=l;
-      p+=l;
+    rv=GWEN_MDigest_Begin(md);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
     }
 
-    return 0;
+    rv=GWEN_MDigest_Update(md, pSeed, lSeed);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+
+    rv=GWEN_MDigest_Update(md, counter, 4);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+
+    rv=GWEN_MDigest_End(md);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+
+    l=GWEN_MDigest_GetDigestSize(md);
+    if (bytesLeft<l)
+      l=bytesLeft;
+    memmove(p, GWEN_MDigest_GetDigestPtr(md), l);
+    bytesLeft-=l;
+    p+=l;
+  }
+
+  return 0;
 }
 
 
 
 int GWEN_Padd_AddPkcs1Pss(uint8_t *pDestBuffer,
-			  uint32_t lDestBuffer,
-			  uint32_t nbits,
-			  const uint8_t *pHash,
-			  uint32_t lHash,
-			  uint32_t lSalt,
-			  GWEN_MDIGEST *md) {
+                          GWEN_UNUSED uint32_t lDestBuffer,
+                          uint32_t nbits,
+                          const uint8_t *pHash,
+                          uint32_t lHash,
+                          uint32_t lSalt,
+                          GWEN_MDIGEST *md)
+{
   uint32_t emLen;
   uint8_t *pSalt=NULL;
   uint8_t *pDB;
@@ -492,7 +523,7 @@ int GWEN_Padd_AddPkcs1Pss(uint8_t *pDestBuffer,
   }
 
   /* generate salt */
-  pSalt=(uint8_t*) malloc(lSalt);
+  pSalt=(uint8_t *) malloc(lSalt);
   assert(pSalt);
   GWEN_Crypt_Random(2, pSalt, lSalt);
 
@@ -533,12 +564,12 @@ int GWEN_Padd_AddPkcs1Pss(uint8_t *pDestBuffer,
   }
   /* hashMBar=HASH(M') */
   memmove(hashMBar,
-	  GWEN_MDigest_GetDigestPtr(md),
-	  GWEN_MDigest_GetDigestSize(md));
+          GWEN_MDigest_GetDigestPtr(md),
+          GWEN_MDigest_GetDigestSize(md));
 
   /* generate DB (PS | '01' | SALT) */
   x=emLen-GWEN_MDigest_GetDigestSize(md)-lSalt-2;
-  pDB=(uint8_t*)malloc(emLen);
+  pDB=(uint8_t *)malloc(emLen);
   assert(pDB);
   p=pDB;
   memset(p, 0, x);
@@ -549,10 +580,10 @@ int GWEN_Padd_AddPkcs1Pss(uint8_t *pDestBuffer,
 
   /* create DBMask */
   x=emLen-GWEN_MDigest_GetDigestSize(md)-1;
-  pDbMask=(uint8_t*)malloc(x);
+  pDbMask=(uint8_t *)malloc(x);
   rv=GWEN_Padd_MGF1(pDbMask, x,
-		    hashMBar, GWEN_MDigest_GetDigestSize(md),
-		    md);
+                    hashMBar, GWEN_MDigest_GetDigestSize(md),
+                    md);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     free(pDbMask);
@@ -586,12 +617,13 @@ int GWEN_Padd_AddPkcs1Pss(uint8_t *pDestBuffer,
 
 
 int GWEN_Padd_VerifyPkcs1Pss(const uint8_t *pSrcBuffer,
-			     uint32_t lSrcBuffer,
-			     uint32_t nbits,
-			     const uint8_t *pHash,
-			     uint32_t lHash,
-			     uint32_t lSalt,
-			     GWEN_MDIGEST *md) {
+                             uint32_t lSrcBuffer,
+                             uint32_t nbits,
+                             const uint8_t *pHash,
+                             uint32_t lHash,
+                             uint32_t lSalt,
+                             GWEN_MDIGEST *md)
+{
   uint32_t emLen;
   const uint8_t *pSalt;
   uint8_t *pDB;
@@ -628,18 +660,18 @@ int GWEN_Padd_VerifyPkcs1Pss(const uint8_t *pSrcBuffer,
   /* check for length of provided data */
   if (lSrcBuffer < emLen) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Bad padding: Provided data too small (is %d, expected %d)",
-	      lSrcBuffer, emLen);
+              lSrcBuffer, emLen);
     return GWEN_ERROR_BAD_DATA;
   }
 
   /* get DB (PS | '01' | SALT) */
   x=emLen-GWEN_MDigest_GetDigestSize(md)-1;
 
-  pDB=(uint8_t*)malloc(x);
+  pDB=(uint8_t *)malloc(x);
   hashMBar=pSrcBuffer+x;
   rv=GWEN_Padd_MGF1(pDB, x,
-		    hashMBar, GWEN_MDigest_GetDigestSize(md),
-		    md);
+                    hashMBar, GWEN_MDigest_GetDigestSize(md),
+                    md);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     free(pDB);
@@ -669,7 +701,7 @@ int GWEN_Padd_VerifyPkcs1Pss(const uint8_t *pSrcBuffer,
   /* check for length of salt */
   if ((x-i)!=lSalt) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Bad padding: bad length for salt (is %d, should be %d)",
-	      x-i, lSalt);
+              x-i, lSalt);
     free(pDB);
     return GWEN_ERROR_BAD_DATA;
   }
@@ -715,8 +747,8 @@ int GWEN_Padd_VerifyPkcs1Pss(const uint8_t *pSrcBuffer,
     return rv;
   }
   if (memcmp(hashMBar,
-	     GWEN_MDigest_GetDigestPtr(md),
-	     GWEN_MDigest_GetDigestSize(md))!=0) {
+             GWEN_MDigest_GetDigestPtr(md),
+             GWEN_MDigest_GetDigestSize(md))!=0) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Bad padding: hash does not match");
 
     free(pDB);
@@ -731,7 +763,8 @@ int GWEN_Padd_VerifyPkcs1Pss(const uint8_t *pSrcBuffer,
 
 
 
-int GWEN_Padd_ApplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf) {
+int GWEN_Padd_ApplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf)
+{
   int rv;
   unsigned int diff;
   unsigned int bsize;
@@ -759,9 +792,9 @@ int GWEN_Padd_ApplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf) {
   diff=dstSize-bsize;
 
   DBG_INFO(GWEN_LOGDOMAIN, "Padding with algo \"%s\"",
-	   GWEN_Crypt_PaddAlgoId_toString(aid));
+           GWEN_Crypt_PaddAlgoId_toString(aid));
 
-  switch(aid) {
+  switch (aid) {
   case GWEN_Crypt_PaddAlgoId_None:
     rv=0;
     break;
@@ -769,8 +802,8 @@ int GWEN_Padd_ApplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf) {
   case GWEN_Crypt_PaddAlgoId_Iso9796_1A4:
     if (dstSize>96) {
       DBG_ERROR(GWEN_LOGDOMAIN,
-		"Padding size must be <=96 bytes (is %d)",
-		dstSize);
+                "Padding size must be <=96 bytes (is %d)",
+                dstSize);
       return GWEN_ERROR_INVALID;
     }
     rv=GWEN_Padd_PaddWithISO9796(buf);
@@ -801,13 +834,13 @@ int GWEN_Padd_ApplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf) {
   case GWEN_Crypt_PaddAlgoId_Iso9796_1:
   default:
     DBG_INFO(GWEN_LOGDOMAIN, "Algo-Type %d (%s) not supported",
-	     aid, GWEN_Crypt_PaddAlgoId_toString(aid));
+             aid, GWEN_Crypt_PaddAlgoId_toString(aid));
     return GWEN_ERROR_NOT_AVAILABLE;
   }
 
   if (rv) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Error padding with algo %d (%s)",
-	      aid, GWEN_Crypt_PaddAlgoId_toString(aid));
+              aid, GWEN_Crypt_PaddAlgoId_toString(aid));
     return GWEN_ERROR_GENERIC;
   }
 
@@ -816,7 +849,8 @@ int GWEN_Padd_ApplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf) {
 
 
 
-int GWEN_Padd_UnapplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf){
+int GWEN_Padd_UnapplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf)
+{
   int rv;
   GWEN_CRYPT_PADDALGOID aid;
 
@@ -825,9 +859,9 @@ int GWEN_Padd_UnapplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf){
 
   aid=GWEN_Crypt_PaddAlgo_GetId(a);
   DBG_INFO(GWEN_LOGDOMAIN, "Unpadding with algo \"%s\"",
-	   GWEN_Crypt_PaddAlgoId_toString(aid));
+           GWEN_Crypt_PaddAlgoId_toString(aid));
 
-  switch(aid) {
+  switch (aid) {
   case GWEN_Crypt_PaddAlgoId_None:
     rv=0;
     break;
@@ -852,13 +886,13 @@ int GWEN_Padd_UnapplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf){
   case GWEN_Crypt_PaddAlgoId_Iso9796_1A4:
   default:
     DBG_INFO(GWEN_LOGDOMAIN, "Algo-Type %d (%s) not supported",
-	     aid, GWEN_Crypt_PaddAlgoId_toString(aid));
+             aid, GWEN_Crypt_PaddAlgoId_toString(aid));
     return GWEN_ERROR_NOT_AVAILABLE;
   }
 
   if (rv) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Error padding with algo %d (%s)",
-	      aid, GWEN_Crypt_PaddAlgoId_toString(aid));
+              aid, GWEN_Crypt_PaddAlgoId_toString(aid));
     return GWEN_ERROR_GENERIC;
   }
 
@@ -867,6 +901,73 @@ int GWEN_Padd_UnapplyPaddAlgo(const GWEN_CRYPT_PADDALGO *a, GWEN_BUFFER *buf){
 
 
 
+int GWEN_Padd_PaddWithZka(GWEN_BUFFER *src)
+{
+  return GWEN_Padd_PaddWithZkaToMultipleOf(src, 16);
+}
 
 
 
+int GWEN_Padd_PaddWithZkaToMultipleOf(GWEN_BUFFER *src, int y)
+{
+  unsigned char paddLength;
+  unsigned int i;
+
+  paddLength=y-(GWEN_Buffer_GetUsedBytes(src) % y);
+  if (paddLength>0) {
+    GWEN_Buffer_AppendByte(src, 0x80);
+    for (i=1; i<paddLength; i++)
+      GWEN_Buffer_AppendByte(src, 0x0);
+  }
+  return 0;
+}
+
+
+
+int GWEN_Padd_UnpaddWithZkaFromMultipleOf(GWEN_BUFFER *buf, int y)
+{
+  const uint8_t *p;
+  unsigned int lastpos;
+  unsigned char paddLength;
+  paddLength=0;
+
+  lastpos=GWEN_Buffer_GetUsedBytes(buf);
+  if (lastpos<y) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer too small");
+    return -1;
+  }
+  lastpos--;
+  p=(const uint8_t *)GWEN_Buffer_GetStart(buf)+lastpos;
+
+  while (*p==0x00) {
+    paddLength++;
+    p--;
+  }
+
+  /* first pad byte must be 0x80 */
+  if (*p==0x80) {
+    paddLength++;
+    p--;
+  }
+  else if (paddLength>0) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Invalid padding, first pad byte has wrong value %xd (%d bytes ?)", *p, paddLength);
+    return -1;
+  }
+
+  if (paddLength<0 || paddLength>y) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Invalid padding (%d bytes ?)", paddLength);
+    return -1;
+  }
+  GWEN_Buffer_Crop(buf, 0, GWEN_Buffer_GetUsedBytes(buf)-paddLength);
+  GWEN_Buffer_SetPos(buf, lastpos-paddLength);
+  return 0;
+}
+
+
+
+int GWEN_Padd_UnpaddWithZka(GWEN_BUFFER *buf)
+{
+  return GWEN_Padd_UnpaddWithZkaFromMultipleOf(buf, 16);
+}
+
+
