@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -55,6 +52,7 @@ extern "C" {
 
 /** @name Error Codes */
 /*@{*/
+/*@TODO: remove this */
 #define GWEN_INETADDR_ERROR_TYPE "InetAddr"
 #define GWEN_INETADDR_ERROR_MEMORY_FULL          1
 #define GWEN_INETADDR_ERROR_BAD_ADDRESS          2
@@ -75,7 +73,7 @@ extern "C" {
 #define GWEN_INETADDR_CAPS_AF_TCP  0x00000001
 #define GWEN_INETADDR_CAPS_AF_UNIX 0x00000002
 
-GWENHYWFAR_API uint32_t GWEN_InetAddr_GetCapabilities();
+GWENHYWFAR_API uint32_t GWEN_InetAddr_GetCapabilities(void);
 /*@}*/
 
 
@@ -143,8 +141,8 @@ GWENHYWFAR_API int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name)
  * @param bsize size of the buffer in bytes
  */
 GWENHYWFAR_API
-  int GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
-                                          char *buffer, unsigned int bsize);
+int GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
+                             char *buffer, unsigned int bsize);
 
 /**
  * Gets the host name stored in the INETADDRESS. If there is none, then the
@@ -155,8 +153,8 @@ GWENHYWFAR_API
  * @param bsize size of the buffer in bytes
  */
 GWENHYWFAR_API
-  int GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
-                                       char *buffer, unsigned int bsize);
+int GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
+                          char *buffer, unsigned int bsize);
 /*@}*/
 
 /**
@@ -179,7 +177,7 @@ GWENHYWFAR_API int GWEN_InetAddr_GetPort(const GWEN_INETADDRESS *ia);
  * @param port port to set (0-65535)
  */
 GWENHYWFAR_API int GWEN_InetAddr_SetPort(GWEN_INETADDRESS *ia,
-					 int port);
+                                         int port);
 /*@}*/
 
 
