@@ -44,6 +44,12 @@ struct GWEN_PROCESS {
   GWEN_SYNCIO *stdIn;
   GWEN_SYNCIO *stdOut;
   GWEN_SYNCIO *stdErr;
+
+  char *filenameStdIn;
+  char *filenameStdOut;
+  char *filenameStdErr;
+
+  char *folder;
 };
 
 GWEN_PROCESS_STATE GWEN_Process_MakeState(GWEN_PROCESS *pr, DWORD status);
