@@ -134,22 +134,24 @@ static int _buildEndHeaders(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty)
   hl=Typemaker2_Type_GetHeaders(ty);
   if (hl) {
     TYPEMAKER2_HEADER *h;
+    int markAdded=0;
 
     h=Typemaker2_Header_List_First(hl);
-    if (h) {
-      GWEN_Buffer_AppendString(tbuf, "/* end-headers */\n");
-      while (h) {
-        if (Typemaker2_Header_GetLocation(h)==Typemaker2_HeaderLocation_HeaderEnd) {
-          GWEN_Buffer_AppendString(tbuf, "#include ");
-
-          if (Typemaker2_Header_GetType(h)==Typemaker2_HeaderType_System)
-            GWEN_Buffer_AppendArgs(tbuf, "<%s>", Typemaker2_Header_GetFileName(h));
-          else
-            GWEN_Buffer_AppendArgs(tbuf, "\"%s\"", Typemaker2_Header_GetFileName(h));
-          GWEN_Buffer_AppendString(tbuf, "\n");
+    while (h) {
+      if (Typemaker2_Header_GetLocation(h)==Typemaker2_HeaderLocation_HeaderEnd) {
+        if (!markAdded) {
+          GWEN_Buffer_AppendString(tbuf, "/* end-headers */\n");
+          markAdded=1;
         }
-        h=Typemaker2_Header_List_Next(h);
+        GWEN_Buffer_AppendString(tbuf, "#include ");
+
+        if (Typemaker2_Header_GetType(h)==Typemaker2_HeaderType_System)
+          GWEN_Buffer_AppendArgs(tbuf, "<%s>", Typemaker2_Header_GetFileName(h));
+        else
+          GWEN_Buffer_AppendArgs(tbuf, "\"%s\"", Typemaker2_Header_GetFileName(h));
+        GWEN_Buffer_AppendString(tbuf, "\n");
       }
+      h=Typemaker2_Header_List_Next(h);
     }
     GWEN_Buffer_AppendString(tbuf, "\n");
   }
@@ -493,6 +495,7 @@ static int _buildInlines(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty)
     }
     ty=Typemaker2_Type_GetExtendsPtr(ty);
   }
+  GWEN_Buffer_free(tbuf);
 
   return 0;
 }
@@ -501,15 +504,15 @@ static int _buildInlines(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty)
 
 static int _buildMemberInlines(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty)
 {
+  TYPEMAKER2_TYPE *structType;
   GWEN_BUFFER *tbuf;
-  uint32_t flags;
   /* TYPEMAKER2_TYPEMANAGER *tym; */
 
+  structType=ty;
+
   /* tym=Typemaker2_Builder_GetTypeManager(tb); */
   tbuf=GWEN_Buffer_new(0, 256, 0, 1);
 
-  flags=Typemaker2_Type_GetFlags(ty);
-
   while (ty) {
     TYPEMAKER2_MEMBER_LIST *tml;
 
@@ -520,15 +523,18 @@ static int _buildMemberInlines(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty)
       tm=Typemaker2_Member_List_First(tml);
       while (tm) {
         TYPEMAKER2_TYPE *mty;
+        uint32_t memberFlags;
 
-        mty=Typemaker2_Member_GetTypePtr(tm);
-        if (mty) {
+        memberFlags=Typemaker2_Member_GetFlags(tm);
+	mty=Typemaker2_Member_GetTypePtr(tm);
+	/* TODO: Check that we don't create duplicate code here!! */
+        if (mty && mty!=structType && mty!=ty) {
           TYPEMAKER2_INLINE *ti;
 
           /* get inlines from member type */
           ti=Typemaker2_Inline_List_First(Typemaker2_Type_GetInlines(mty));
           while (ti) {
-            if ((flags & Typemaker2_Inline_GetTypeFlagsMask(ti))==Typemaker2_Inline_GetTypeFlagsValue(ti)) {
+            if ((memberFlags & Typemaker2_Inline_GetTypeFlagsMask(ti))==Typemaker2_Inline_GetTypeFlagsValue(ti)) {
               const char *content;
 
               content=Typemaker2_Inline_GetContent(ti);
